summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/audio/trackfld.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/audio/trackfld.cpp')
-rw-r--r--src/mame/audio/trackfld.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/audio/trackfld.cpp b/src/mame/audio/trackfld.cpp
index 77c474809c5..bf139f858e9 100644
--- a/src/mame/audio/trackfld.cpp
+++ b/src/mame/audio/trackfld.cpp
@@ -132,11 +132,11 @@ WRITE_LINE_MEMBER(trackfld_audio_device::sh_irqtrigger_w)
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void trackfld_audio_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void trackfld_audio_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
// should never get here
- fatalerror("sound_stream_update called; not applicable to legacy sound devices\n");
+ fatalerror("sound_stream_update_legacy called; not applicable to legacy sound devices\n");
}
@@ -132,11 +132,11 @@ WRITE_LINE_MEMBER(trackfld_audio_device::sh_irqtrigger_w)
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------